@@ -169,12 +169,18 @@ private slots:
   void testMemberFunctionModifiers();
 
   void testContextSearch();
-  
-  void testFinalCleanup();
+
   void testEllipsis();
 
   void testMultiByteCStrings();
 
+  void testUses();
+  void testCtorTypes();
+
+  void testAutoTypeIntegral_data();
+  void testAutoTypeIntegral();
+  void testAutoTypes();
+
 private:
   void assertNoMemberFunctionModifiers(KDevelop::ClassFunctionDeclaration* memberFun);
 
