@@ -45,6 +45,23 @@
 QStringList headerExtensions(QString("h,H,hh,hxx,hpp,tlh,h++").split(','));
 QStringList sourceExtensions(QString("c,cc,cpp,c++,cxx,C,m,mm,M,inl,_impl.h").split(','));
 
+template<class T>
+QList<T> makeListUnique(QList<T> list)
+{
+  QList<T> ret;
+  
+  QSet<T> set;
+  foreach(T item, list)
+  {
+    if(!set.contains(item))
+    {
+      ret << item;
+      set.insert(item);
+    }
+  }
+  
+  return ret;
+}
 
 QString addDot(QString ext) {
   if(ext.contains('.')) //We need this check because of the _impl.h thing
@@ -183,6 +200,9 @@ bool isHeader(const KUrl &url) {
 
 QStringList standardIncludePaths()
 {
+  static QMutex mutex;
+  QMutexLocker lock(&mutex); //Make sure we don't call computeGccStandardMacros() twice at the same time
+  
   static QStringList list = CppTools::setupStandardIncludePaths();
   return list;
 }
@@ -190,6 +210,9 @@ QStringList standardIncludePaths()
 
 const Cpp::ReferenceCountedMacroSet& standardMacros()
 {
+  static QMutex mutex;
+  QMutexLocker lock(&mutex); //Make sure we don't call computeGccStandardMacros() twice at the same time
+  
   static Cpp::ReferenceCountedMacroSet macros = CppTools::setupStandardMacros();
   return macros;
 }
@@ -206,7 +229,7 @@ QPair<KUrl, KUrl> findInclude(const KUrl::List& includePaths, const KUrl& localP
         QFileInfo info(includeName);
         if (info.exists() && info.isReadable() && info.isFile()) {
             //kDebug(9007) << "found include file:" << info.absoluteFilePath();
-            ret.first = KUrl(info.absoluteFilePath());
+            ret.first = KUrl(info.canonicalFilePath());
             ret.first.cleanPath();
             ret.second = KUrl("/");
             return ret;
@@ -218,7 +241,7 @@ QPair<KUrl, KUrl> findInclude(const KUrl::List& includePaths, const KUrl& localP
         QFileInfo info(check);
         if (info.exists() && info.isReadable() && info.isFile()) {
             //kDebug(9007) << "found include file:" << info.absoluteFilePath();
-            ret.first = KUrl(info.absoluteFilePath());
+            ret.first = KUrl(info.canonicalFilePath());
             ret.first.cleanPath();
             ret.second = localPath;
             return ret;
@@ -242,7 +265,7 @@ restart:
 
         if (info.exists() && info.isReadable() && info.isFile()) {
             //kDebug(9007) << "found include file:" << info.absoluteFilePath();
-            ret.first = KUrl(info.absoluteFilePath());
+            ret.first = KUrl(info.canonicalFilePath());
             ret.first.cleanPath();
             ret.second = path.toLocalFile();
             return ret;
@@ -318,6 +341,7 @@ QList<KDevelop::IncludeItem> allFilesInIncludePath(const KUrl& source, bool loca
       }
     }
 
+    paths = makeListUnique<KUrl>(paths);
     int pathNumber = 0;
 
     foreach(const KUrl& path, paths)
