@@ -217,12 +217,10 @@ KDevVarLengthArray<KDevVarLengthArray<QPair<uint, TOKEN_KIND>, 10 >, index_size
   ADD_TOKEN(xor_eq);
   ADD_TOKEN(__qt_signal__);
   ADD_TOKEN(__qt_slot__);
+  ADD_TOKEN(__qt_property__);
   return ret;
 }
 
-//A very simple lookup table: First level contains all pairs grouped by with (index % index_size), then there is a simple list
-KDevVarLengthArray<KDevVarLengthArray<QPair<uint, TOKEN_KIND>, 10 >, index_size > indicesForTokens = createIndicesForTokens();
-
 scan_fun_ptr Lexer::s_scan_table[256];
 bool Lexer::s_initialized = false;
 
@@ -491,6 +489,9 @@ void Lexer::scan_identifier_or_keyword()
   }
   
   uint bucket = (*cursor.current) % index_size;
+
+  //A very simple lookup table: First level contains all pairs grouped by with (index % index_size), then there is a simple list
+  static const KDevVarLengthArray<KDevVarLengthArray<QPair<uint, TOKEN_KIND>, 10 >, index_size > indicesForTokens = createIndicesForTokens();
   for(int a = 0; a < indicesForTokens[bucket].size(); ++a) {
     if(indicesForTokens[bucket][a].first == *cursor.current) {
       (*session->token_stream)[index++].kind = indicesForTokens[bucket][a].second;
