@@ -21,17 +21,20 @@
 
 #include "default_visitor.h"
 
+class ParseSession;
+
 /**
  * Sets the parent node of each AST node. The root node won't have a parent set.
  */
 class ParentVisitor : public DefaultVisitor
 {
   public:
-    ParentVisitor();
+    ParentVisitor(ParseSession* session);
     virtual void visit(AST* node);
 
   private:
     AST *m_currentParent;
+    ParseSession* m_session;
 };
 
 #endif // PARENTVISITOR_H
