@@ -71,6 +71,12 @@ public:
 
   void mapAstUse(AST *node, const SimpleUse& use);
 
+  ///Create a mapping between an AST node and its parent.
+  void mapAstParent(AST *node, AST *parent);
+
+  /// Visits the tree and sets the appropriate nodes as parent on each node of the tree.
+  void setASTNodeParents();
+
   /**
    * \brief Request an AST node from a DeclarationPointer
    * \return The Associated AST if available, NULL otherwise
@@ -81,6 +87,12 @@ public:
 
   AST * astNodeFromUse(const SimpleUse &use) const;
 
+  /**
+   * \brief Access the parent node for a given AST.
+   * \return Parent AST node or NULL for the root node.
+   */
+  AST * parentAstNode(AST* node);
+
   /**
    * \brief Request a Declaration from an AST node
    * \return The Associated Declaration if available, empty DeclarationPointer otherwise
@@ -103,9 +115,6 @@ public:
   /// Unweildy name, but we want to be clear here, if there is already a location table, this would be the wrong setup function to call
   void setContentsAndGenerateLocationTable(const PreprocessedContents& contents);
 
-  /// Visits the tree and sets the appropriate nodes as parent on each node of the tree.
-  void setASTNodeParents();
-
   void setUrl(const KDevelop::IndexedString& url);
   const KDevelop::IndexedString& url() const;
 
@@ -129,6 +138,8 @@ private:
 
   QMap<AST *, SimpleUse> m_AstToUse;
   QMap<SimpleUse, AST *> m_UseToAst;
+
+  QMap<AST *, AST *> m_AstToParent;
 };
 
 #endif
