@@ -124,7 +124,9 @@ static char const * const _S_token_names[] = {
   "whitespaces",
   "xor",
   "xor_eq",
-  "__qt_sig_slot__"
+  "__qt_signal__",
+  "__qt_slot__",
+  "__qt_property__"
 };
 
 static char const * const _S_token_texts[] = {
@@ -230,7 +232,9 @@ static char const * const _S_token_texts[] = {
   "whitespaces",
   "^",
   "^=",
-  "__qt_sig_slot__"
+  "__qt_signal__",
+  "__qt_slot__",
+  "__qt_property__"
 };
 
 static char _S_printable[][2] = {
