@@ -117,6 +117,9 @@ private slots:
   void testStringProblem();
   void testArgumentList();
   void testStaticMethods();
+  void testStringInComment_data();
+  void testStringInComment();
+  void testProperties();
   void testAnonStruct();
   void testOverrideCtor();
 
