@@ -65,8 +65,8 @@ class DUChainAttatched
 class CMakeFolderItem : public KDevelop::ProjectBuildFolderItem, public DescriptorAttatched
 {
     public:
-        CMakeFolderItem( KDevelop::IProject *project, const QString &name, const QString& builddir, CMakeFolderItem* parent);
-        virtual ~CMakeFolderItem() {}
+        CMakeFolderItem( KDevelop::IProject* project, const KUrl& folder, const QString& build, CMakeFolderItem* item);
+        
         void setIncludeDirectories(const QStringList &l) { m_includeList=l; }
         QStringList includeDirectories() const;
         CMakeDefinitions definitions() const { return m_defines; }
@@ -82,6 +82,14 @@ class CMakeFolderItem : public KDevelop::ProjectBuildFolderItem, public Descript
         void setFormerParent(CMakeFolderItem* parent) { m_formerParent=parent; }
         
         QString buildDir() const { return m_buildDir; }
+        
+        void clear();
+        void setEnabled(bool);
+
+        KDevelop::ProjectTargetItem* targetNamed(Target::Type type, const QString& targetName) const;
+        KDevelop::ProjectFolderItem* folderNamed(const QString& name) const;
+        void cleanupBuildFolders(const QList< Subdirectory >& subs);
+        void cleanupTargets(const QList<CMakeTarget>& targets);
     private:
         KDevelop::ReferencedTopDUContext m_topcontext;
         QStringList m_includeList;
