@@ -32,6 +32,10 @@
 #include "cmakelistsparser.h"
 #include "cmakeparserutils.h"
 
+#define CMAKE_REGISTER_AST( klassName, astId ) namespace {                 \
+        CMakeAst* Create##klassName() { return new klassName; }            \
+        bool b_##astId = AstFactory::self()->registerAst( QLatin1String( #astId ), Create##klassName ); }
+
 CMAKE_REGISTER_AST( AddDefinitionsAst, add_definitions )
 CMAKE_REGISTER_AST( AddDependenciesAst, add_dependencies )
 CMAKE_REGISTER_AST( AddExecutableAst, add_executable )
@@ -113,6 +117,7 @@ CMAKE_REGISTER_AST( VariableRequiresAst, variable_requires )
 CMAKE_REGISTER_AST( WhileAst, while)
 CMAKE_REGISTER_AST( WriteFileAst, write_file)
 
+#undef CMAKE_REGISTER_AST
 
 enum Stage {NAMES, PATHS, PATH_SUFFIXES, HINTS};
 
@@ -652,6 +657,7 @@ bool BuildNameAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 }
 
 CMakeMinimumRequiredAst::CMakeMinimumRequiredAst()
+    : m_wrongVersionIsFatal(false)
 {
 }
 
@@ -2090,6 +2096,8 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
         m_type = Sort;
     else if(argName=="REVERSE")
         m_type = Reverse;
+    else if(argName=="REMOVE_DUPLICATES")
+        m_type = RemoveDuplicates;
     else
         return false;
 
@@ -2107,17 +2115,20 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
                 return false;
             
             addOutputArgument(func.arguments[1]);
-            bool correct;
             addOutputArgument(func.arguments.last());
+            
             m_output = func.arguments.last().value;
-            m_index.append(func.arguments[2].value.toInt(&correct));
-            if(!correct)
-                return false;
-            int i=0;
-            foreach(const CMakeFunctionArgument& arg, func.arguments)
+            
+            QList<CMakeFunctionArgument>::const_iterator it=func.arguments.constBegin()+2, itEnd=func.arguments.constEnd();
+            int i=2;
+            bool correct;
+            for(; it!=itEnd; ++it)
             {
-                if(i>2 && i<func.arguments.count())
-                    m_elements.append(arg.value);
+                if(i!=func.arguments.size()-1) {
+                    m_index.append(it->value.toInt(&correct));
+                    if(!correct)
+                        return false;
+                }
                 i++;
             }
         } break;
@@ -2163,11 +2174,11 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
                 return false;
             int i=0;
             addOutputArgument(func.arguments[1]);
-            foreach(const CMakeFunctionArgument& arg, func.arguments)
+            
+            QList<CMakeFunctionArgument>::const_iterator it=func.arguments.constBegin()+2, itEnd=func.arguments.constEnd();
+            for(; it!=itEnd; ++it)
             {
-                if(i>2)
-                    m_elements.append(arg.value);
-                i++;
+                m_elements.append(it->value);
             }
         } break;
         case RemoveAt: {
@@ -2189,6 +2200,7 @@ bool ListAst::parseFunctionInfo( const CMakeFunctionDesc& func )
         } break;
         case Sort:
         case Reverse:
+        case RemoveDuplicates:
             addOutputArgument(func.arguments[1]);
             if(func.arguments.count()>2)
                 return false;
@@ -3127,6 +3139,7 @@ bool TargetLinkLibrariesAst::parseFunctionInfo( const CMakeFunctionDesc& func )
     if ( func.arguments.size() < 2 )
         return false;
 
+    m_target = func.arguments[0].value;
 
     QList<CMakeFunctionArgument>::const_iterator it, itEnd;
     it = func.arguments.begin() + 1;
@@ -3490,7 +3503,7 @@ BreakAst::~BreakAst()
 
 bool BreakAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
-    return func.arguments.isEmpty() && func.name.toLower()=="break";
+    return func.name.toLower()=="break";
 }
 
 CMakePolicyAst::CMakePolicyAst()
@@ -3556,6 +3569,7 @@ ExportAst::~ExportAst()
 }
 
 
+/// @todo Implement EXPORT(PACKAGE name), introduced in CMake 2.8
 bool ExportAst::parseFunctionInfo( const CMakeFunctionDesc& func )
 {
     if(func.name.toLower()!="export" || func.arguments.count() < 2 || func.arguments[0].value!="TARGETS")
@@ -3599,7 +3613,7 @@ bool ExportAst::parseFunctionInfo( const CMakeFunctionDesc& func )
             opt=TARGETS;
         }
     }
-    return !m_targets.isEmpty();
+    return !m_filename.isEmpty();
 }
 
 ReturnAst::ReturnAst()
