@@ -49,8 +49,12 @@
 
 using namespace KDevelop;
 
+void debugMsgs(const QString& message) { kDebug(9032) << "message:" << message; }
+
+CMakeProjectVisitor::message_callback CMakeProjectVisitor::s_msgcallback=debugMsgs;
+
 CMakeProjectVisitor::CMakeProjectVisitor(const QString& root, ReferencedTopDUContext parent)
-    : m_root(root), m_vars(0), m_macros(0), m_topctx(0), m_parentCtx(parent)
+    : m_root(root), m_vars(0), m_macros(0), m_topctx(0), m_parentCtx(parent), m_hitBreak(false)
 {
 }
 
@@ -557,7 +561,6 @@ int CMakeProjectVisitor::visit(const FindPackageAst *pack)
 {
     if(!haveToFind(pack->name()))
         return 1;
-    const QStringList modulePath = m_vars->value("CMAKE_MODULE_PATH") + m_modulePath;
     kDebug(9042) << "Find:" << pack->name() << "package." << m_modulePath << "No module: " << pack->noModule();
 
     QStringList possibleModuleNames;
@@ -581,8 +584,9 @@ int CMakeProjectVisitor::visit(const FindPackageAst *pack)
     kDebug(9042) << "config mode" << m_vars->value(var).join(QString()) << m_cache->value(var).value << instPath;
 
     #if defined(Q_OS_WIN)
-    modulePath.prepend(instPath);
-    modulePath.prepend(instPath+"/cmake");
+    const QStringList modulePath = QStringList() << instPath + "/cmake" << instPath << m_vars->value("CMAKE_MODULE_PATH") + m_modulePath;
+    #else
+    const QStringList modulePath = m_vars->value("CMAKE_MODULE_PATH") + m_modulePath;
     #endif
     QString name=pack->name();
     QStringList postfix=QStringList() << QString() << "/cmake" << "/CMake";
@@ -1479,7 +1483,7 @@ int CMakeProjectVisitor::visit(const FileAst *file)
 
 int CMakeProjectVisitor::visit(const MessageAst *msg)
 {
-    kDebug(9032) << "message:" << msg->message();
+    s_msgcallback(msg->message().join(QString()));
     return 1;
 }
 
@@ -1553,6 +1557,7 @@ int CMakeProjectVisitor::visit(const OptionAst *opt)
 int CMakeProjectVisitor::visit(const ListAst *list)
 {
     QString output = list->output();
+    
     QStringList theList = m_vars->value(list->list());
     switch(list->type())
     {
@@ -1561,29 +1566,30 @@ int CMakeProjectVisitor::visit(const ListAst *list)
             kDebug(9042) << "List length" << m_vars->value(output);
             break;
         case ListAst::Get: {
+            bool contains = m_vars->contains(list->list());
             QStringList indices;
-            foreach(int idx, list->index())
-            {
-                if(idx>=theList.count() || idx < 0)
-                    kDebug(9032) << "error! trying to GET an element that doesn't exist!" << idx;
-                else
-                    indices += theList[idx];
-            }
+            if(contains) {
+                foreach(int idx, list->index())
+                {
+                    if(idx>=theList.count())
+                        kDebug(9032) << "error! trying to GET an element that doesn't exist!" << idx;
+                    else if(idx>=0)
+                        indices += theList[idx];
+                    else
+                        indices += theList[theList.size()+idx];
+                }
+            } else
+                indices += "NOTFOUND";
             m_vars->insert(output, indices);
-            kDebug(9042) << "List: Get" << list->list() << theList << list->output() << m_vars->value(list->output());
+            kDebug(9042) << "List: Get" << list->list() << theList << list->output() << list->index();
         }   break;
         case ListAst::Append:
             theList += list->elements();
             m_vars->insert(list->list(), theList);
             break;
         case ListAst::Find: {
-            int idx=-1;
-            foreach(const QString& val, theList)
-            {
-                if(val==list->elements().first())
-                    break;
-                idx++;
-            }
+            int idx=theList.indexOf(list->elements().first());
+            
             m_vars->insert(list->output(), QStringList(QString::number(idx)));
             kDebug(9042) << "List: Find" << theList << list->output() << list->elements() << idx;
         }   break;
@@ -1591,8 +1597,8 @@ int CMakeProjectVisitor::visit(const ListAst *list)
             int p=list->index().first();
             foreach(const QString& elem, list->elements())
             {
-                theList.insert(p, elem);
-                p++;
+                theList.insert(p >=0 ? p : (theList.size()+p), elem);
+                p += p>=0? 1 : 0;
             }
             m_vars->insert(list->list(), theList);
         }   break;
@@ -1610,11 +1616,11 @@ int CMakeProjectVisitor::visit(const ListAst *list)
             qSort(indices);
             QList<int>::const_iterator it=indices.constEnd();
             kDebug(9042) << "list remove: " << theList << indices;
-            while(it!=indices.constBegin())
+            do
             {
                 --it;
-                theList.removeAt(*it);
-            }
+                theList.removeAt(*it >= 0 ? *it : theList.size()+*it);
+            } while(it!=indices.constBegin());
             m_vars->insert(list->list(), theList);
         }   break;
         case ListAst::Sort:
@@ -1628,6 +1634,14 @@ int CMakeProjectVisitor::visit(const ListAst *list)
             m_vars->insert(list->list(), reversed);
             }
             break;
+        case ListAst::RemoveDuplicates: {
+            QStringList noduplicates;
+            foreach(const QString& elem, theList) {
+                if(!noduplicates.contains(elem))
+                    noduplicates.append(elem);
+            }
+            m_vars->insert(list->list(), noduplicates);
+        }   break;
     }
     kDebug(9042) << "List!!" << list->output() << '='<< m_vars->value(list->output()) << " -> " << m_vars->value(list->list());
     return 1;
@@ -1984,10 +1998,13 @@ int CMakeProjectVisitor::visit( const WhileAst * whileast)
     int end=whileast->line()+1;
     if(result)
     {
-        end=walk(whileast->content(), whileast->line()+1);
-        if(end<whileast->content().size() && whileast->content()[end].name.toUpper()!="BREAK") {
+        walk(whileast->content(), whileast->line()+1);
+        
+        if(m_hitBreak) {
+            kDebug() << "break found. leaving loop";
+            m_hitBreak=false;
+        } else
             walk(whileast->content(), whileast->line());
-        }
     }
     CMakeFileContent::const_iterator it=whileast->content().constBegin()+end;
     CMakeFileContent::const_iterator itEnd=whileast->content().constEnd();
@@ -2023,7 +2040,7 @@ CMakeFunctionDesc CMakeProjectVisitor::resolveVariables(const CMakeFunctionDesc
     return ret;
 }
 
-enum RecursivityType { No, Yes, End };
+enum RecursivityType { No, Yes, End, Break };
 
 RecursivityType recursivity(const QString& functionName)
 {
@@ -2031,10 +2048,10 @@ RecursivityType recursivity(const QString& functionName)
     if(upperFunctioName=="IF" || upperFunctioName=="WHILE" ||
        upperFunctioName=="FOREACH" || upperFunctioName=="MACRO")
         return Yes;
-    else if(upperFunctioName=="ELSE" || upperFunctioName=="ELSEIF")
-        return End;
-    else if(upperFunctioName.startsWith("END") || upperFunctioName=="BREAK")
+    else if(upperFunctioName=="ELSE" || upperFunctioName=="ELSEIF" || upperFunctioName.startsWith("END"))
         return End;
+    else if(upperFunctioName=="BREAK")
+        return Break;
     return No;
 }
 
@@ -2066,6 +2083,19 @@ int CMakeProjectVisitor::walk(const CMakeFileContent & fc, int line, bool isClea
 
         Q_ASSERT( *it == fc[line] );
 //         kDebug(9042) << "At line" << line << "/" << fc.count();
+
+        RecursivityType r = recursivity(it->name);
+        if(r==End || r==Break || m_hitBreak)
+        {
+//             kDebug(9042) << "Found an end." << func.writeBack();
+            m_backtrace.pop();
+            m_topctx=aux;
+            
+            if(r==Break)
+                m_hitBreak=true;
+            return line;
+        }
+        
         CMakeAst* element = AstFactory::self()->createAst(it->name);
 
         if(!element)
@@ -2083,17 +2113,6 @@ int CMakeProjectVisitor::walk(const CMakeFileContent & fc, int line, bool isClea
                 << " at" << func.filePath << ":" << func.line << endl;
             //FIXME: Should avoid to run?
         }
-
-        RecursivityType r = recursivity(func.name);
-        if(r==End)
-        {
-//             kDebug(9042) << "Found an end." << func.writeBack();
-            delete element;
-            m_backtrace.pop();
-            m_topctx=aux;
-            return line;
-        } else if(r==Yes)
-            m_loopType.push(func.name.toUpper());
         
         if(element->isDeprecated()) {
             kDebug(9032) << "Warning: Using the function: " << func.name << " which is deprecated by cmake.";
